@@ -11,7 +11,6 @@ import matplotlib.pyplot as plt
 import torch
 tf.io.gfile = tb.compat.tensorflow_stub.io.gfile
 from eli5.permutation_importance import get_score_importances
-from pdpbox import pdp, get_dataset, info_plots
 from captum.attr import IntegratedGradients
 from captum.attr import visualization as viz
 from captum.attr import GuidedGradCam, LayerGradCam, LayerAttribution
@@ -153,23 +152,6 @@ class ComprehensibilityAnalysis:
             plt.title(title)
             plt.show()
 
-    def partial_plot(self, feature_names):
-        """
-        Scipy only
-        :param feature_names:
-        :return:
-        """
-        x_test_numpy = self.interface.to_numpy(self.x_test)
-        print(x_test_numpy.shape)
-        print(feature_names)
-        df = pd.DataFrame(x_test_numpy, columns=feature_names)
-        print(df)
-        pdp_goals = pdp.pdp_isolate(model=self.model, dataset=df, model_features=feature_names,
-                                    feature='0')
-
-        pdp.pdp_plot(pdp_goals, '0')
-        plt.show()
-
     def vis_feature_importance(self, feature_names, class_label=0, title='Average Feature Importances', plot=True,
                                axis_title='Features'):
         """
